@@ -14,10 +14,12 @@
  * limitations under the License.
  */
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file gss_assist/source/acquire.c
+ * @file acquire.c
  * @author Sam Lang, Sam Meder
  */
+#endif
 
 #include "globus_i_gss_assist.h"
 #include "gssapi.h"
